"""
A module for every constant of asymmetric.
"""

# HTTP related
HTTP_METHODS = [
    "get",
    "put",
    "post",
    "delete",
    "options",
    "head",
    "patch",
    "trace",
]

# Docs
OPENAPI_SPEC_ROUTE = "/openapi.json"
SWAGGER_DOCUMENTATION_ROUTE = "/docs"
REDOC_DOCUMENTATION_ROUTE = "/redoc"
